# Copyright (C) 2008 severalnines.com
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; version 2
# of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
#
# You should have received a copy of the GNU Library General Public
# License along with this library; if not, write to the Free
# Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
# MA 02111-1307, USA

AC_DEFUN([ACX_MYSQL], [

  AC_MSG_CHECKING(for mysql_config executable)

  AC_ARG_WITH([mysql],
    [AS_HELP_STRING([--with-mysql=PATH],
        [path to mysql_config binary or mysql prefix dir])],
      [with_mysql=$withval],
      [with_mysql=mysql_config])

   AS_IF([test -f $with_mysql -a -x $with_mysql],
      [MYSQL_CONFIG=$with_mysql],
      [AS_IF([test -f $with_mysql/bin/mysql_config -a -x $with_mysql/bin/mysql_config],
        [MYSQL_CONFIG=$with_mysql/bin/mysql_config])])

  AS_IF([test "x$with_mysql" = "xmysql_config"],
    AC_CHECK_PROGS(MYSQL_CONFIG,[$with_mysql]))

  AS_IF([test "x$MYSQL_CONFIG" = "x"],
    AC_MSG_ERROR([MySQL not found]))


    AC_PROG_CC
    AC_PROG_CXX

    AC_LANG(C++)
    # add regular MySQL C flags
    ADDCFLAGS=`$MYSQL_CONFIG --cflags`
    # add NdbAPI specific C flags
    IBASE=`$MYSQL_CONFIG --include`
    ADDIFLAGS="$IBASE/storage/ndb"
    ADDIFLAGS="$ADDIFLAGS $IBASE/storage/ndb/ndbapi"
    ADDIFLAGS="$ADDIFLAGS $IBASE/storage/ndb/mgmapi"
    ADDIFLAGS="$ADDIFLAGS $IBASE/ndb"
    ADDIFLAGS="$ADDIFLAGS $IBASE/ndb/ndbapi"
    ADDIFLAGS="$ADDIFLAGS $IBASE/ndb/mgmapi"
    ADDIFLAGS="$ADDIFLAGS $IBASE"

    CFLAGS="$CFLAGS $ADDCFLAGS $ADDIFLAGS"
    CXXFLAGS="$CXXFLAGS $ADDCFLAGS $ADDIFLAGS"
    MYSQL_INCLUDES="$IBASE $ADDIFLAGS"

    LDFLAGS="$LDFLAGS "`$MYSQL_CONFIG --libs_r`

#    AC_CHECK_LIB([ndbclient],[decimal_bin_size],,[
#      AC_CHECK_LIB([ndbhelper],[decimal_bin_size],,[
#        AC_CHECK_LIB([mysys],[my_thread_init])
#        AC_CHECK_LIB([mystrings],[decimal_bin_size])
#      ])
#      AC_CHECK_LIB([ndbclient],[ndb_init],,[AC_MSG_ERROR([Can't link against libndbclient])])
#    ])
    
    MYSQL_MAJOR_VERSION=`$MYSQL_CONFIG --version | sed -e 's/\.//g' -e 's/-//g' -e 's/[A-Za-z]//g' | cut -c1-2`

    case "$MYSQL_MAJOR_VERSION" in
      50) AC_DEFINE(MYSQL_50, [1], [mysql5.0])
        ;;
      51) AC_DEFINE(MYSQL_51, [1], [mysql5.1])
        ;;
      *) echo "Unsupported version of MySQL Detected!"
        ;;
     esac

    AC_SUBST(MYSQL_MAJOR_VERSION)

    AS_IF([test "$MYSQL_MAJOR_VERSION" = "51"],
       [AC_MSG_RESULT(ok)],
       [AC_MSG_ERROR([MySQL 5.0 is not supported, you have to use MySQL Cluster 6.2 or later])])

    AC_SUBST(MYSQL_CONFIG)

    
    AC_MSG_CHECKING(for ndbapi headers)
     AC_TRY_LINK([#include <NdbApi.hpp>], [int attr=NdbTransaction::Commit; ],
                        [ndbapi_found="yes"])
    AS_IF([test "$ndbapi_found" = "yes"],
       [AC_MSG_RESULT(found them, we have NDBAPI support)],
       [AC_MSG_WARN([Couldn't find NdbApi.h!])])
 
 if test `uname -s` = "Darwin"; then
    LDFLAGS="$LDFLAGS -lmystrings -lmysys $LIBS"
 else
    LDFLAGS="$LDFLAGS -lmystrings -lmysys -lrt $LIBS"
 fi
    if test "$ndbapi_found" = "yes"; then
         AC_DEFINE(NDB,[1], [if we have ndbapi])
         AC_SUBST(NDB )
         LDFLAGS="$LDFLAGS -lndbclient"
    fi

    


])
